pqi-native-1.0.1.2: Native (pure-Haskell) adapter for pqi
Safe HaskellNone
LanguageHaskell2010

Pqi.Native

Description

The native (pure-Haskell) pqi adapter.

adapter bundles the three functions that produce a Connection whose fields are closures over the underlying native Connection (which speaks the PostgreSQL wire protocol directly). Result and Cancel values are constructed the same way, in Pqi.Native.Types.

Synopsis

Documentation

adapter :: Adapter Source #

The native adapter.