| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Pqi.Native
Description
The native (pure-Haskell) pqi adapter.
adapter bundles the three functions that produce a Connection
whose fields are closures over the underlying native Connection
(which speaks the PostgreSQL wire protocol directly). Result and
Cancel values are constructed the same way, in Pqi.Native.Types.